#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup

setup(
    name='base30-korean',
    version='0.0.2',
    py_modules=['base30_korean'],
    author='Joseph Kim',
    author_email='iz4blue@gmail.com',
    description='crockford base32를 한국어 실정에 맞게 변형한 base30',
    url='https://github.com/iz4blue/base30-korean',
    license='BSD',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3.6',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Utilities',
        'Natural Language :: Korean',
    ],
)



# -*- coding: utf-8 -*-

# http://www.crockford.com/wrmg/base32.html 의 base32 를 기준으로
# 한국어의 발음상 E 와 2 가 같은 것을 고려,
# 한국어의 발음상 5 와 O 가 같은 것을 고려,
# 읽고 쓰기 편한 것을 목적으로 u 와 v 을 같은 문자로 취급
symbols = '012346789ABCDFGHJKMNPQRSTVWXYZ'


def encode(number):
    if int(number) < 0:
        raise ValueError("'%d' 은 양수가 아닙니다" % number)

    value = int(number)
    if value == 0:
        return '0'

    output = ''
    while value > 0:
        char = value % len(symbols)
        value //= len(symbols)
        output = symbols[char] + output

    return output


def decode(source):
    trantab = bytearray.maketrans(b'5EeIiLlOoUu', b'022111100VV')

    string = source.translate(trantab)
    string.upper()

    number = 0
    for char in string:
        number = number * len(symbols) + symbols.index(char)

    return number
